<?php
/**
*
* Style Changer extension for the phpBB Forum Software package.
* @copyright (c) 2010 created Prime Quick Style Mod for phpBB 3.0.7 by primehalo http://www.absoluteanime.com
* @copyright (c) 2014 - 2024 created an Extension by Kirk https://reyno41.bplaced.net/phpbb
* @license GNU General Public License, version 2 (GPL-2.0-only)
*
*/

namespace kirk\stylechanger\controller;

class stylechanger_acp_controller
{
	protected $auth;
	protected $config;
	protected $language;
	protected $request;
	protected $template;
	protected $md_manager;
	protected $phpbb_admin_path;
	protected $php_ext;
	protected $u_action;

	public function __construct(
		\phpbb\auth\auth $auth,
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\request\request $request,
		\phpbb\template\template $template,
		\phpbb\extension\manager $ext_manager,
		\phpbb\path_helper $path_helper,
		$php_ext
	)
	{
		$this->auth					= $auth;
		$this->config				= $config;
		$this->language				= $language;
		$this->request				= $request;
		$this->template				= $template;
		$this->php_ext				= $php_ext;
		$this->phpbb_admin_path		= $path_helper->get_phpbb_root_path() . $path_helper->get_adm_relative_path();
		$this->md_manager			= $ext_manager->create_extension_metadata_manager('kirk/stylechanger')->get_metadata('all');
	}

	public function stylechanger_settings($u_action)
	{
		// Style Changer settings
		$form_key						= 'acp_stylechanger';
		$this->u_action					= $u_action;
		$perm_can_manage_users			= $this->auth->acl_get('a_authusers');
		$perm_can_manage_groups			= $this->auth->acl_get('a_authgroups');
		$u_user_perm					= append_sid("{$this->phpbb_admin_path}index.$this->php_ext" ,'i=acp_permissions&amp;mode=setting_user_global');
		$u_group_perm					= append_sid("{$this->phpbb_admin_path}index.$this->php_ext" ,'i=acp_permissions&amp;mode=setting_group_global');
		$u_board_settings				= append_sid("{$this->phpbb_admin_path}index.$this->php_ext" ,'i=acp_board&amp;mode=settings');
		$u_stylechanger_setings			= append_sid("{$this->phpbb_admin_path}index.$this->php_ext" ,'i=-kirk-stylechanger-acp-stylechanger_module&amp;mode=settings');
		$stylechanger_activated			= $this->config['stylechanger_activated'];
		$stylechanger_adminmode			= $this->config['stylechanger_adminmode'];
		$override_user_style_activated	= $this->config['override_user_style'];
		$disp_ext_name					= $this->md_manager['extra']['display-name'];
		$stylechanger_version			= $this->md_manager['version'];
		$stylechanger_colon				= $this->language->lang('COLON');
		$stylechanger_config_updated	= $this->language->lang('CONFIG_UPDATED');
		$submit							= $this->request->is_set_post('submit');
		$stylechanger_perm_info			= '';
		$stylechanger_notes				= '';
		$this->language->add_lang('stylechanger_acp', 'kirk/stylechanger');
		add_form_key($form_key);

		if ($submit)
		{
			if (!check_form_key($form_key))
			{
				trigger_error($this->language->lang('FORM_INVALID') . adm_back_link($this->u_action), E_USER_WARNING);
			}
			$this->config->set('stylechanger_activated', $this->request->variable('stylechanger_activated', ''));
			$this->config->set('stylechanger_adminmode', $this->request->variable('stylechanger_adminmode', ''));
			$this->config->set('stylechanger_fa_icon_activated', $this->request->variable('stylechanger_fa_icon_activated', ''));
			$this->config->set('stylechanger_font_icon', $this->request->variable('stylechanger_font_icon', ''));
			$this->config->set('stylechanger_ucp_user_style', $this->request->variable('stylechanger_ucp_user_style', ''));
			$this->config->set('stylechanger_toggle_activated', $this->request->variable('stylechanger_toggle_activated', ''));
			meta_refresh(2, $u_stylechanger_setings);
			trigger_error($this->language->lang('STYLECHANGER_SETTINGS_UPDATED', $disp_ext_name, $stylechanger_colon, $stylechanger_config_updated) . adm_back_link($this->u_action));
		}

		// Style Changer perm info
		if ($perm_can_manage_users && $perm_can_manage_groups)
		{
			$this->add_stylechanger_perm_info($stylechanger_perm_info, $this->language->lang('STYLECHANGER_PERMISSION_INFO', $u_user_perm, $u_group_perm));
		}
		else if ($perm_can_manage_users)
		{
			$this->add_stylechanger_perm_info($stylechanger_perm_info, $this->language->lang('STYLECHANGER_PERMISSION_INFO_USER', $u_user_perm));
		}
		else if ($perm_can_manage_groups)
		{
			$this->add_stylechanger_perm_info($stylechanger_perm_info, $this->language->lang('STYLECHANGER_PERMISSION_INFO_GROUP', $u_group_perm));
		}

		// Style Changer notes
		if (!$stylechanger_activated)
		{
			$this->add_stylechanger_note($stylechanger_notes, $this->language->lang('STYLECHANGER_DEACTIVATED'));
		}
		if ($stylechanger_adminmode)
		{
			$this->add_stylechanger_note($stylechanger_notes, $this->language->lang('STYLECHANGER_ADMINMODE_ACTIVATED'));
		}
		if ($override_user_style_activated)
		{
			$this->add_stylechanger_note($stylechanger_notes, $this->language->lang('STYLECHANGER_USER_STYLE_OVERRIDE', $u_board_settings));
		}

		$this->template->assign_vars([
			'STYLECHANGER_PERM_INFO'			=> $stylechanger_perm_info,
			'STYLECHANGER_NOTES'				=> $stylechanger_notes,
			'STYLECHANGER_ACTIVATED'			=> $stylechanger_activated,
			'STYLECHANGER_ADMINMODE'			=> $stylechanger_adminmode,
			'OVERRIDE_USER_STYLE_ACTIVATED'		=> $override_user_style_activated,
			'STYLECHANGER_FA_ICON_ACTIVATED'	=> $this->config['stylechanger_fa_icon_activated'],
			'STYLECHANGER_FONT_ICON'			=> $this->config['stylechanger_font_icon'],
			'STYLECHANGER_UCP_USER_STYLE'		=> $this->config['stylechanger_ucp_user_style'],
			'STYLECHANGER_TOGGLE_ACTIVATED'		=> $this->config['stylechanger_toggle_activated'],
			'OVERIDE_USERSTYLE_ACTIVATED'		=> $override_user_style_activated,
			'STYLECHANGER_VERSION_COPY'			=> $this->language->lang('STYLECHANGER_VERSION_COPY', $disp_ext_name, $stylechanger_version),
			'U_ACTION'							=> $this->u_action
		]);
	}

	private function add_stylechanger_note(string &$stylechanger_notes, string $msg)
	{
		$stylechanger_notes .= (($stylechanger_notes != '') ? "\n" : "") . sprintf('<p>%s</p>', $msg);
	}

	private function add_stylechanger_perm_info(string &$stylechanger_perm_info, string $msg)
	{
		$stylechanger_perm_info .= (($stylechanger_perm_info != '') ? "\n" : "") . sprintf('%s', $msg);
	}
}
