<?php
/**
*
* Style Changer extension for the phpBB Forum Software package.
* @copyright (c) 2010 created Prime Quick Style Mod for phpBB 3.0.7 by primehalo http://www.absoluteanime.com
* @copyright (c) 2014 - 2024 created an Extension by Kirk https://reyno41.bplaced.net/phpbb
* @license GNU General Public License, version 2 (GPL-2.0-only)
*
*/

namespace kirk\stylechanger\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	protected $auth;
	protected $config;
	protected $language;
	protected $request;
	protected $template;
	protected $db;
	protected $user;
	protected $phpbb_root_path;
	protected $php_ext;
	protected $sc_perm;
	protected $override_user_style;
	protected $user_style;
	protected $user_id;
	protected $registered_user;
	protected $default_style;

	public function __construct(
		\phpbb\auth\auth $auth,
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\request\request_interface $request,
		\phpbb\template\template $template,
		\phpbb\db\driver\driver_interface $db,
		\phpbb\user $user,
		$phpbb_root_path,
		$php_ext
	)
	{
		$this->config					= $config;
		$this->language					= $language;
		$this->request					= $request;
		$this->template					= $template;
		$this->db						= $db;
		$this->user						= $user;
		$this->phpbb_root_path			= $phpbb_root_path;
		$this->php_ext					= $php_ext;

		// Variables for Stylechanger
		$this->sc_perm					= $auth->acl_get('u_view_stylechanger');
		$this->override_user_style		= $config['override_user_style'];
		$this->user_style				= $user->data['user_style'];
		$this->default_style			= $config['default_style'];
		$this->user_id					= $user->data['user_id'];
		$this->registered_user			= $user->data['is_registered'];
	}

	/**
	* Assign functions defined in this class to event listeners in the core
	*
	* @return array
	*/
	public static function getSubscribedEvents()
	{
		return [
			'core.user_setup'					=> [['set_guest_style'], ['default_style']],
			'core.permissions'					=> 'permissions',
			'core.page_header_after'			=> 'select_style_form',
			'core.ucp_display_module_before'	=> 'switch_style',
			'core.ucp_prefs_modify_common'		=> 'show_hide_ucp_user_style'
		];
	}

	/**
	* Load permission event
	*/
	public function permissions($event)
	{
		$permissions = $event['permissions'];
		$permissions += [
			'u_view_stylechanger'	=> [
			'lang'					=> 'ACL_U_VIEW_STYLECHANGER',
			'cat'					=> 'misc'
			],
		];
		$event['permissions'] = $permissions;
	}

	/**
	* Check if user should be able to access Style Changer
	*/
	public function select_style_form()
	{
		if ($this->sc_perm)
		{
			$this->language->add_lang('stylechanger', 'kirk/stylechanger');
			$current_style = ($this->registered_user) ? $this->user_style : $this->request_cookie('style', $this->user_style);
			$style_options = style_select($this->request->variable('style', (int) $current_style));
			if (substr_count($style_options, '<option') > 1)
			{
				$redirect = 'redirect=' . urlencode(str_replace(['&amp;', '../'], ['&', ''], build_url('style')));
				$action = append_sid("{$this->phpbb_root_path}ucp.$this->php_ext", 'i=prefs&amp;mode=personal&amp;' . $redirect);
				$action = preg_replace('/(?:&amp;|(\?))style=[^&]*(?(1)&amp;|)?/i', "$1", $action);
				$this->template->assign_vars([
					'S_STYLECHANGE_ACTION'				=> $action,
					'S_STYLECHANGE_OPTIONS'				=> $this->override_user_style ? '' : $style_options,
					'STYLECHANGER_ACTIVATED'			=> $this->config['stylechanger_activated'],
					'STYLECHANGER_ADMINMODE'			=> $this->config['stylechanger_adminmode'],
					'STYLECHANGER_FA_ICON_ACTIVATED'	=> $this->config['stylechanger_fa_icon_activated'],
					'STYLECHANGER_FONT_ICON'			=> $this->config['stylechanger_font_icon']
				]);
			}
		}
	}

	/**
	* The UCP event is only triggered when the user is logged in.
	*/
	public function switch_style()
	{
		if (!$this->override_user_style && $style = $this->request->variable('stylechanger', 0))
		{
			$style = ($this->override_user_style) ? $this->default_style : $style;
			$sql = 'UPDATE ' . USERS_TABLE . '
					SET user_style = ' . (int) $style .'
					WHERE user_id = ' . (int) $this->user_id;
			$this->db->sql_query($sql);
			// Redirect the user back to last viewed page
			$redirect = urldecode($this->request->variable('redirect', $this->user->data['session_page']));
			$redirect = reapply_sid($redirect);
			redirect($redirect);
		}
	}

	/**
	* Set Default style when the user/group has no Permission "Can view the Style Changer".
	*/
	public function default_style()
	{
		if (!$this->sc_perm && $this->config['stylechanger_ucp_user_style'])
		{
			$sql = 'UPDATE ' . USERS_TABLE . '
					SET user_style = ' . (int) $this->default_style .'
					WHERE user_id = ' . (int) $this->user_id;
			$this->db->sql_query($sql);
		}
	}

	/**
	* Handle style switching by guests (User not logged in)
	*/
	public function set_guest_style($event)
	{
		if (!$this->override_user_style && $this->sc_perm && $this->user_id == ANONYMOUS)
		{
			$style = $event['style_id'];
			// Set the style to display
			$event['style_id'] = ($style) ? $style : $this->request_cookie('style', (int) ($this->user_style));

			// Set the cookie (and redirect) when the style is switched
			if ($style = $this->request->variable('stylechanger', 0))
			{
				$style = ($this->override_user_style) ? $this->default_style : $style;
				$this->user->set_cookie('style', $style, 0);
				// Redirect the user back to their last viewed page
				$redirect = urldecode($this->request->variable('redirect', $this->user->data['session_page']));
				$redirect = reapply_sid($redirect);
				redirect($redirect);
			}
		}
	}

	public function request_cookie($name, $default = null)
	{
		$name = $this->config['cookie_name'] . '_' . $name;
		return $this->request->variable($name, $default, false, 3);
	}

	public function show_hide_ucp_user_style()
	{
		$this->template->assign_vars([
			'S_STYLE_OPTIONS'	=> $this->config['stylechanger_ucp_user_style'] || $this->override_user_style ? '' : style_select($this->user_style)
		]);
	}
}
